@@ -6,7 +6,7 @@
 import tarfile
 import tempfile
 
-from swh.model.identifiers import ObjectType
+from swh.model.swhids import ObjectType
 from swh.vault.cookers.base import BaseVaultCooker
 from swh.vault.to_disk import DirectoryBuilder
 
